@@ -358,7 +358,7 @@ def Interaction(data,bodyPart,fields):
 
     for i in range(len(interact)):
         for j in range(numObjects):
-            if fields['obj'][0] == 0:
+            if fields['fields'][0] == 0:
                 if ((dataX[i] - fields['center_x'][j])**2 + (dataY[i] - fields['center_y'][j])**2 <= fields['radius'][j]**2):
                     interact[i] = j +1
             else:
